Home
last modified time | relevance | path

Searched defs:shared (Results 1 – 19 of 19) sorted by relevance

/llvm-project-15.0.7/llvm/include/llvm/ExecutionEngine/Orc/
H A DEPCGenericMemoryAccess.h44 using namespace shared; in writeUInt8sAsync() local
51 using namespace shared; in writeUInt16sAsync() local
58 using namespace shared; in writeUInt32sAsync() local
65 using namespace shared; in writeUInt64sAsync() local
72 using namespace shared; in writeBuffersAsync() local
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Dbuiltins-amdgcn.cu53 __shared__ float shared; in test_ds_fmax() local
70 __shared__ float shared; in test_ds_fadd() local
96 __global__ void test_ds_fmin(float src, float *shared) { in test_ds_fmin()
201 __global__ void test_ds_fmin_func(float src, float *__restrict shared) { in test_ds_fmin_func()
/llvm-project-15.0.7/libcxx/test/libcxx/memory/trivial_abi/
H A Dunique_ptr_arg.pass.cpp34 __attribute__((noinline)) void expect_1(int* shared, bool /*unused*/) { in expect_1()
39 int shared = 0; in main() local
H A Dshared_ptr_arg.pass.cpp35 __attribute__((noinline)) void expect_1(int* shared, bool /*unused*/) { in expect_1()
40 int shared = 0; in main() local
H A Dunique_ptr_array.pass.cpp35 __attribute__((noinline)) void expect_3(int* shared, bool /*unused*/) { in expect_3()
40 int shared = 0; in main() local
/llvm-project-15.0.7/lld/test/ELF/Inputs/
H A Dppc64-toc-relax-shared.s5 shared: label
H A Dsymbol-ordering-file-warnings1.s7 shared: label
/llvm-project-15.0.7/llvm/lib/ExecutionEngine/Orc/Shared/
H A DAllocationActions.cpp13 namespace shared { namespace
/llvm-project-15.0.7/compiler-rt/test/tsan/libdispatch/
H A Dgroups-destructor.cpp26 std::shared_ptr<MyStruct> shared(new MyStruct()); in main() local
/llvm-project-15.0.7/llvm/lib/ExecutionEngine/Orc/
H A DEPCGenericDylibManager.cpp17 namespace shared { namespace
H A DMachOPlatform.cpp27 namespace shared { namespace
/llvm-project-15.0.7/clang/test/CodeGenObjCXX/
H A Dmangle.mm12 + (A *)shared { class
/llvm-project-15.0.7/lldb/include/lldb/Target/
H A DMemoryRegionInfo.h29 OptionalBool execute, OptionalBool shared, in MemoryRegionInfo()
/llvm-project-15.0.7/lld/wasm/
H A DConfig.h51 bool shared; member
/llvm-project-15.0.7/polly/lib/External/ppcg/
H A Dgpu_group.c1010 isl_union_map *shared; in shared_access() local
H A Dgpu.c3260 struct gpu_array_ref_group *group, int shared) in add_group_write_sync()
/llvm-project-15.0.7/lld/ELF/
H A DConfig.h222 bool shared; member
/llvm-project-15.0.7/polly/lib/External/isl/
H A Disl_flow.c2967 isl_schedule_node *shared; in before_node() local
H A Disl_ast_codegen.c3307 isl_set *shared, *inner; in has_pure_outer_disjunction() local